@@ -74,6 +74,11 @@ void Kytea::addTag(typename Dictionary<Entry>::WordMap& allWords, const KyteaStr
             Entry::setInDict(it->second->inDict,dict);
     }
 }
+
+
+template
+void Kytea::addTag<ModelTagEntry>(Dictionary<ModelTagEntry>::WordMap& allWords, const KyteaString & word, int lev, const KyteaString * tag, int dict);
+
 template <class Entry>
 void Kytea::addTag(typename Dictionary<Entry>::WordMap& allWords, const KyteaString & word, const KyteaTag * tag, int dict) {
     addTag<Entry>(allWords,word,(tag?&tag->first:0),dict);
